# plot

The `mypy-baseline plot` draws a chart of the baseline size change over time using [plotnine](https://github.com/has2k1/plotnine).

It works in a similar manner to [mypy-baseline history](./history.md). You also need a git repository and the git itself. You also need plotnine to be installed.

```bash
python3 -m pip install plotnine
python3 -m mypy_baseline plot
```
